@@ -1,4 +1,3 @@
-#!/usr/bin/env python
 # -*- coding: utf-8 -*-
 from __future__ import print_function
 
@@ -20,11 +19,12 @@ from tempfile import _TemporaryFileWrapper as TemporaryFileWrapperBase
 from clu.constants.consts import λ, DELETE_FLAG, ENCODING, PATH, SCRIPT_PATH
 from clu.constants.exceptions import ExecutionError, FilesystemError
 from clu.constants.polyfills import lru_cache, scandir, walk
+from clu.dicts import OrderedItemsView, OrderedKeysView, OrderedValuesView
 from clu.predicates import attr, allattrs, anyof
 from clu.sanitizer import utf8_encode
-from clu.typology import ispath, isvalidpath
-from .misc import filesize, gethomedir, masked_permissions
-from .misc import stringify, suffix_searcher, swapext, u8str
+from clu.typology import isnotpath, isvalidpath
+from clu.fs.misc import differentfile, filesize, gethomedir, masked_permissions
+from clu.fs.misc import stringify, suffix_searcher, swapext, u8str
 from clu.exporting import ValueDescriptor, Exporter
 
 exporter = Exporter(path=__file__)
@@ -36,7 +36,7 @@ DEFAULT_PREFIX = "yo-dogg-"
 @export
 def ensure_path_is_valid(pth):
     """ Raise an exception if we can’t write to the specified path """
-    if not ispath(pth):
+    if isnotpath(pth):
         raise FilesystemError(f"Operand must be a path type: {pth}")
     if os.path.exists(pth):
         if os.path.isdir(pth):
@@ -194,26 +194,26 @@ def back_tick(command,  as_str=True,
     return (as_str and output.decode(encoding) or output)
 
 @export
-def rm_rf(pth):
+def rm_rf(path):
     """ rm_rf() does what `rm -rf` does – so, for the love of fuck,
         BE FUCKING CAREFUL WITH IT.
     """
-    if not isvalidpath(pth):
+    if not isvalidpath(path):
         raise ExecutionError(
             "Can’t rm -rf without something to rm arr-effedly")
-    pth = os.fspath(pth)
+    path = os.fspath(path)
     try:
-        if os.path.isfile(pth) or os.path.islink(pth):
-            os.unlink(pth)
-        elif os.path.isdir(pth):
+        if os.path.isfile(path) or os.path.islink(path):
+            os.unlink(path)
+        elif os.path.isdir(path):
             subdirs = []
-            for path, dirs, files in walk(pth, followlinks=True):
+            for root, dirs, files in walk(path, followlinks=True):
                 for tf in files:
-                    os.unlink(os.path.join(path, tf))
-                subdirs.extend([os.path.join(path, td) for td in dirs])
+                    os.unlink(os.path.join(root, tf))
+                subdirs.extend((os.path.join(root, td) for td in dirs))
             for subdir in reversed(subdirs):
                 os.rmdir(subdir)
-            os.rmdir(pth)
+            os.rmdir(path)
         return True
     except (OSError, IOError):
         pass
@@ -246,6 +246,7 @@ def temporary(suffix='', prefix='', parent=None, **kwargs):
         raise FilesystemError(f"temporary(): file exists: {fullpth}")
     return fullpth
 
+@export
 class TypeLocker(abc.ABCMeta):
     
     """ clu.fs.filesystem.TypeLocker is a metaclass that does two
@@ -415,7 +416,7 @@ class TemporaryName(collections.abc.Hashable,
     fields = ('name',   'exists', 
                         'destroy',
               'mode',   'binary_mode',
-              'prefix', 'suffix', 'parent')
+              'prefix', 'suffix', 'dirname')
     
     def __init__(self, prefix=None, suffix="tmp",
                        parent=None,
@@ -563,8 +564,8 @@ class TemporaryName(collections.abc.Hashable,
         return filesize(self._name)
     
     def split(self):
-        """ Return (dirname, basename) e.g. for /yo/dogg/i/heard/youlike,
-            you get back (Directory("/yo/dogg/i/heard"), "youlike")
+        """ Return (dirname, basename) e.g. for /yo/dogg/i/heard/youlike.jpg,
+            you get back (Directory("/yo/dogg/i/heard"), "youlike.jpg")
         """
         return self.dirname, self.basename
     
@@ -645,7 +646,7 @@ class TemporaryName(collections.abc.Hashable,
     
     def to_string(self):
         """ Stringify the TemporaryName instance. """
-        return stringify(self, type(self).fields)
+        return stringify(self, type(self).fields, try_callables=False)
     
     def __repr__(self):
         return self.to_string()
@@ -665,7 +666,7 @@ class TemporaryName(collections.abc.Hashable,
         return self.exists
     
     def __eq__(self, other):
-        if not ispath(other):
+        if isnotpath(other):
             return NotImplemented
         try:
             return os.path.samefile(self._name,
@@ -674,11 +675,11 @@ class TemporaryName(collections.abc.Hashable,
             return False
     
     def __ne__(self, other):
-        if not ispath(other):
+        if isnotpath(other):
             return NotImplemented
         try:
-            return not os.path.samefile(self._name,
-                                        os.fspath(other))
+            return differentfile(self._name,
+                                 os.fspath(other))
         except FileNotFoundError:
             return True
     
@@ -690,6 +691,7 @@ non_dotfile_matcher = lambda p: non_dotfile_match(p.name)
 
 @export
 class Directory(collections.abc.Hashable,
+                collections.abc.Reversible,
                 collections.abc.Mapping,
                 collections.abc.Sized,
                 contextlib.AbstractContextManager,
@@ -864,8 +866,7 @@ class Directory(collections.abc.Hashable,
         """
         self.ctx_set_targets(old=os.getcwd())
         if os.path.isdir(self.new):
-            self.will_change = not os.path.samefile(self.old,
-                                                    self.new)
+            self.will_change = differentfile(self.old, self.new)
         else:
             self.will_change = False
         self.did_change = False
@@ -1057,12 +1058,14 @@ class Directory(collections.abc.Hashable,
                                                             filename))) \
                                                         for filename in filenames)
                 for iinfile, outfile in zip(iinputs, outputs):
-                    dstfile = shutil.copy2(iinfile, outfile, follow_symlinks=True)
-                    assert os.path.exists(dstfile)
-                    assert os.path.samefile(dstfile, outfile)
-                    results.append(dstfile)
+                    results.append(
+                      shutil.copy2(iinfile, outfile, follow_symlinks=True))
             # Return the destination directory instance and the result list:
             return whereto, tuple(results)
+        else:
+            raise FilesystemError(
+                f"flatten(…) source doesn’t exist: {self.name}")
+        return None, tuple()
     
     def copy_all(self, destination):
         """ Copy the entire directory tree, all contents included, to a new
@@ -1093,7 +1096,7 @@ class Directory(collections.abc.Hashable,
                                    symlinks=False))
         else:
             raise FilesystemError(
-                f"copy_all() source doesn’t exist: {self.name}")
+                f"copy_all(…) source doesn’t exist: {self.name}")
         return False
     
     def zip_archive(self, destination, compression_mode=zipfile.ZIP_DEFLATED):
@@ -1150,6 +1153,18 @@ class Directory(collections.abc.Hashable,
         """ Stringify the Directory instance. """
         return stringify(self, type(self).fields)
     
+    @wraps(dict.items)
+    def items(self):
+        return OrderedItemsView(self)
+    
+    @wraps(dict.keys)
+    def keys(self):
+        return OrderedKeysView(self)
+    
+    @wraps(dict.values)
+    def values(self):
+        return OrderedValuesView(self)
+    
     def __repr__(self):
         return self.to_string()
     
@@ -1168,10 +1183,24 @@ class Directory(collections.abc.Hashable,
         return self.exists
     
     def __iter__(self):
-        return scandir(self.realpath())
+        out = self.exists \
+              and (k.name for k in scandir(
+                                   os.path.realpath(self.name))) \
+               or iter(tuple())
+        yield from out
+    
+    def __reversed__(self):
+        out = self.exists \
+              and (k.name for k in reversed(scandir(
+                                   os.path.realpath(self.name)))) \
+               or iter(tuple())
+        yield from out
     
     def __len__(self):
-        return len(list(self))
+        return self.exists \
+               and len(os.listdir(
+                       os.path.realpath(self.name))) \
+                or 0
     
     def __getitem__(self, filename):
         pth = self.subpath(filename, requisite=True)
@@ -1183,8 +1212,14 @@ class Directory(collections.abc.Hashable,
     def __contains__(self, filename):
         return self.subpath(filename, requisite=True) is not None
     
+    def __truediv__(self, filename):
+        return self.subpath(filename, requisite=False)
+    
+    def __rtruediv__(self, filepath):
+        return self.directory(filepath).subdirectory(self)
+    
     def __eq__(self, other):
-        if not ispath(other):
+        if isnotpath(other):
             return NotImplemented
         try:
             return os.path.samefile(self.name,
@@ -1193,19 +1228,16 @@ class Directory(collections.abc.Hashable,
             return False
     
     def __ne__(self, other):
-        if not ispath(other):
+        if isnotpath(other):
             return NotImplemented
         try:
-            return not os.path.samefile(self.name,
-                                        os.fspath(other))
+            return differentfile(self.name,
+                                 os.fspath(other))
         except FileNotFoundError:
             return True
     
     def __hash__(self):
         return hash((self.name, self.exists))
-    
-    def __call__(self, *args, **kwargs):
-        return self
 
 @export
 class cd(Directory):
@@ -1359,14 +1391,14 @@ class Intermediate(TemporaryDirectory, Directory):
         a new TemporaryDirectory instance instead.
     """
     
-    def __new__(cls, pth=None):
+    def __new__(cls, pth=None, change=False):
         """ The constructor simply delegates to the creation of either a new
             Directory or a new TemporaryDirectory.
         """
         if pth is not None:
             return Directory(pth=pth)
         return TemporaryDirectory(prefix=f"{cls.__name__}-",
-                                  change=False)
+                                  change=change)
     
     def __init__(self, pth=None):
         """ The initializer explicitly does nothing, as it will always be called
