@@ -104,19 +104,19 @@ from clu.typology import (samelength, differentlength, isunique, istypelist, mak
                           path_classes, path_types, file_types,
                           dict_types, mapping_types, mapping_classes,
                           function_types, Λ, callable_types,
-                          ispathtype, ispath, isvalidpath,
+                          ispathtype, ispath, isnotpath, isvalidpath,
                           isaliasdescriptor, hasmembers, hasaliases,
                           isabstractmethod, isabstract, isabstractcontextmanager, iscontextmanager,
                           isnumber, isnumeric, iscomplex, ismapping,
                           isarray, isscalar, isstring, isbytes, ismodule,
                           isfunction, ΛΛ, islambda, λλ,
-                          iscallable, ishashable, issequence,
+                          iscallable, iscallabletype, ishashable, issequence,
                           isxlist, isxtypelist,
                           ispathtypelist, ispathlist, isvalidpathlist,
                           isnumberlist, isnumericlist, iscomplexlist, ismappinglist,
                           isarraylist, isscalarlist, isstringlist, isbyteslist,
                           ismodulelist, isfunctionlist, islambdalist,
-                          iscallablelist, ishashablelist, issequencelist)
+                          iscallablelist, iscallabletypelist, ishashablelist, issequencelist)
 
 from clu.naming import (determine_module, nameof, moduleof,
                         dotpath_join, dotpath_split, qualified_import,
@@ -125,7 +125,7 @@ from clu.naming import (determine_module, nameof, moduleof,
                         dotpath_to_prefix, path_to_prefix,
                         split_abbreviations)
 
-from clu.config.abc import NAMESPACE_SEP, NamespacedMutableMapping, FlatOrderedSet
+from clu.config.abc import NAMESPACE_SEP, NamespacedMutableMapping, Cloneable, FlatOrderedSet
 from clu.config.base import Flat, Nested
 from clu.config.env import Env
 from clu.config.filebase import FileName, FileBase
@@ -137,6 +137,7 @@ from clu.config.settings import Schema
 from clu.config.formats import JsonFile, PickleFile, TomlFile, YamlFile
 
 from clu.csv import pad_csv
+from clu.dicts import OrderedMappingView, OrderedItemsView, OrderedKeysView, OrderedValuesView
 from clu.dicts import merge_two, merge_as, merge, asdict
 
 # Add miscellaneous necessities:
@@ -322,25 +323,25 @@ __all__ = ('Image',
            'path_classes', 'path_types', 'file_types',
            'dict_types', 'mapping_types', 'mapping_classes',
            'function_types', 'Λ', 'callable_types',
-           'ispathtype', 'ispath', 'isvalidpath',
+           'ispathtype', 'ispath', 'isnotpath', 'isvalidpath',
            'isaliasdescriptor', 'hasmembers', 'hasaliases',
            'isabstractmethod', 'isabstract', 'isabstractcontextmanager', 'iscontextmanager',
            'isnumber', 'isnumeric', 'iscomplex', 'ismapping',
            'isarray', 'isscalar', 'isstring', 'isbytes',
            'ismodule', 'isfunction', 'ΛΛ', 'islambda', 'λλ',
-           'iscallable', 'ishashable', 'issequence',
+           'iscallable', 'iscallabletype', 'ishashable', 'issequence',
            'isxlist', 'isxtypelist',
            'ispathtypelist', 'ispathlist', 'isvalidpathlist',
            'isnumberlist', 'isnumericlist', 'iscomplexlist', 'ismappinglist',
            'isarraylist', 'isscalarlist', 'isstringlist', 'isbyteslist',
            'ismodulelist', 'isfunctionlist', 'islambdalist',
-           'iscallablelist', 'ishashablelist', 'issequencelist',
+           'iscallablelist', 'iscallabletypelist', 'ishashablelist', 'issequencelist',
            'determine_module', 'nameof', 'moduleof',
            'dotpath_join', 'dotpath_split',
            'qualified_import', 'qualified_name_tuple', 'qualified_name',
            'dotpath_to_prefix', 'path_to_prefix',
            'split_abbreviations',
-           'NAMESPACE_SEP', 'NamespacedMutableMapping', 'FlatOrderedSet',
+           'NAMESPACE_SEP', 'NamespacedMutableMapping', 'Cloneable', 'FlatOrderedSet',
            'Flat', 'Nested',
            'Env', 'FileName', 'FileBase',
            'ValidationError', 'hoist',
@@ -348,6 +349,7 @@ __all__ = ('Image',
            'FieldBase', 'fields',
            'Schema', 'JsonFile', 'PickleFile', 'TomlFile', 'YamlFile',
            'pad_csv',
+           'OrderedMappingView', 'OrderedItemsView', 'OrderedKeysView', 'OrderedValuesView',
            'merge_two', 'merge_as', 'merge', 'asdict',
            'DUNDER', 'SUNDER', 'alias', 'AliasingEnumMeta', 'AliasingEnum',
            'print_separator', 'evict_announcer',
@@ -401,15 +403,20 @@ try:
                                    ensure_path_is_valid,
                                    script_path, which, back_tick,
                                    rm_rf, temporary,
+                                   TypeLocker,
                                    TemporaryName, Directory,
                                                   cd, wd, td, hd,
                                    TemporaryDirectory, Intermediate,
                                    NamedTemporaryFile)
-    from clu.fs.misc import (gethomedir,
+    from clu.fs.misc import (gethomedir, isinvalidpath,
+                             stringify, stringify_value,
+                             wrap_value,
+                             hexid, typenameof, typename_hexid,
                              re_matcher, re_searcher,
                              re_suffix, suffix_searcher,
                              swapext,
-                             filesize, samesize)
+                             differentfile,
+                             filesize, samesize, differentsize)
 except (ImportError, SyntaxError):
     pass
 else:
@@ -420,15 +427,21 @@ else:
                 'ensure_path_is_valid',
                 'script_path', 'which', 'back_tick',
                 'rm_rf', 'temporary',
+                'TypeLocker',
                 'TemporaryName', 'Directory',
                                  'cd', 'wd', 'td', 'hd',
                 'TemporaryDirectory', 'Intermediate',
                 'NamedTemporaryFile',
-                'gethomedir',
+                'gethomedir', 'isinvalidpath',
+                'stringify', 'stringify_value',
+                'wrap_value',
+                'hexid', 'typenameof', 'typename_hexid',
                 're_matcher', 're_searcher',
                 're_suffix', 'suffix_searcher',
                 'swapext',
-                'filesize', 'samesize')
+                'differentfile',
+                'filesize', 'samesize', 'differentsize')
+    D = Directory()
 
 try:
     from instakit.utils.static import asset
